(compile-attrs attrs)Compile a HTML attribute map.
Compile a HTML attribute map.
(compile-html content)(compile-html content env)Pre-compile data structures into HTML where possible.
Pre-compile data structures into HTML where possible.
(compile-react-element element env)Render an element vector as a HTML element.
Render an element vector as a HTML element.
(infer-tag env form)Infer the tag of form using env.
Infer the tag of `form` using `env`.
(interpret-maybe expr)Macro that wraps expr with a call to
daiquiri.interpreter/interpret if the inferred return type is not a
primitive React type.
Macro that wraps `expr` with a call to `daiquiri.interpreter/interpret` if the inferred return type is not a primitive React type.
(maybe-warn-on-interpret env expr)(maybe-warn-on-interpret env expr tag)(wrap-event-handlers attrs)Wrapping on-change handler to work around async rendering queue that causes jumping caret and lost characters in input fields
Wrapping on-change handler to work around async rendering queue that causes jumping caret and lost characters in input fields
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |